@@ -11,12 +11,11 @@ from google.api_core.exceptions import AlreadyExists, NotFound, BadRequest
 from google.cloud import error_reporting
 from google.cloud import secretmanager
 from pandas.io.sql import DatabaseError
-import mysql.connector
 
 import hashlib
 
 
-def get_sql_data(mysql_con: mysql.connector.connect, query: str) -> pd.core.frame.DataFrame:
+def get_sql_data(mysql_con, query: str) -> pd.core.frame.DataFrame:
     """
     Função para a capturar informação do mysql e retornar em um dataframe
 
